"""Social scrapers."""

from tv_scraper.scrapers.social.ideas import Ideas
from tv_scraper.scrapers.social.minds import Minds
from tv_scraper.scrapers.social.news import News

__all__ = ["Ideas", "Minds", "News"]
